<?php
require __DIR__ . '/vendor/autoload.php';
require __DIR__ . '/db.php'; // Include the db.php file

use Dotenv\Dotenv;

$dotenv = Dotenv::createImmutable(__DIR__);
$dotenv->load();

$error = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $loginKey = $_POST['login_key'] ?? '';
    $username = $_POST['username'] ?? '';
    $password = $_POST['password'] ?? '';

    // Validate inputs
    if (empty($loginKey) || empty($username) || empty($password)) {
        $error = 'Please fill in all required fields.';
    } else {
        // Construct the API URL using the base URL from the .env file
        $apiUrl = $_ENV['API_URL'] . 'key_get_details.php?login_key=' . urlencode($loginKey) . '&user=' . urlencode($username) . '&pass=' . urlencode($password);
        
        // Get the API response
        $response = @file_get_contents($apiUrl);

        if ($response !== false) {
            $data = json_decode($response, true);

            // Debug the response
            error_log(print_r($data, true)); // Log the response data for debugging

            // Check if the response contains status and if it is 1
            if (isset($data['status']) && $data['status'] == 1) {
                // Insert data into the first database
                $db = getInvoiceDbConnection();
                $stmt = $db->prepare("
                    INSERT INTO login_key 
                        (login_key, user, pass, api, imageUrl, rest_id, rest_name, rest_address, rest_phone, rest_logo, rest_link) 
                    VALUES 
                        (:login_key, :user, :pass, :api, :imageUrl, :rest_id, :rest_name, :rest_address, :rest_phone, :rest_logo, :rest_link)
                ");

                $stmt->execute([
                    ':login_key' => $loginKey,
                    ':user' => $username,
                    ':pass' => password_hash($password, PASSWORD_DEFAULT), // Hash the password before storing it
                    ':api' => $data['api'] ?? '',
                    ':imageUrl' => $data['imageUrl'] ?? '',
                    ':rest_id' => $data['rest_id'] ?? '',
                    ':rest_name' => $data['rest_name'] ?? '',
                    ':rest_address' => $data['rest_address'] ?? '',
                    ':rest_phone' => $data['rest_phone'] ?? '',
                    ':rest_logo' => $data['rest_logo'] ?? '',
                    ':rest_link' => $data['rest_link'] ?? '',
                ]);

                // If the first database insertion is successful, proceed with the secondary API call
                $restLink = rtrim($data['rest_link'] ?? '', '/'); // Ensure no trailing slash
                $apiEndpointUrl = "{$restLink}/sync_key.php"; // Append endpoint

                // Debug the constructed API URL
                error_log("Constructed API Endpoint URL: " . $apiEndpointUrl);

                // Send the data to the secondary API
                $ch = curl_init($apiEndpointUrl);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_POST, true);
                curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode([
                    'login_key' => $loginKey,
                    'user' => $username,
                    'pass' => password_hash($password, PASSWORD_DEFAULT), // Ensure password is hashed here too
                    'api' => $data['api'] ?? '',
                    'imageUrl' => $data['imageUrl'] ?? '',
                    'rest_id' => $data['rest_id'] ?? '',
                    'rest_name' => $data['rest_name'] ?? '',
                    'rest_address' => $data['rest_address'] ?? '',
                    'rest_phone' => $data['rest_phone'] ?? '',
                    'rest_logo' => $data['rest_logo'] ?? '',
                    'rest_link' => $data['rest_link'] ?? '',
                ]));
                curl_setopt($ch, CURLOPT_VERBOSE, true); // Enable verbose output for debugging
                curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); // Disable SSL verification (for testing only)
                curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false); // Disable SSL verification (for testing only)

                $result = curl_exec($ch);

                if ($result === false) {
                    $error = 'Curl error: ' . curl_error($ch);
                    error_log($error);
                } else {
                    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
                    error_log("HTTP Status Code: " . $httpCode);
                    
                    $resultData = json_decode($result, true);

                    if ($httpCode == 200 && isset($resultData['status']) && $resultData['status'] === 'success') {
                        // Redirect to login page if secondary API call is successful
                        header('Location: login.php');
                        exit();
                    } else {
                        // Log the error and redirect to login page if the secondary API call fails
                        $error = 'Failed to send data to the secondary API. Response: ' . print_r($resultData, true);
                        error_log($error);
                        header('Location: login.php');
                        exit();
                    }
                }

                curl_close($ch);
            } else {
                $error = 'Activation code not valid or expired. Status: ' . ($data['status'] ?? 'unknown');
            }
        } else {
            $error = 'API is not accessible or invalid response.';
        }
    }
}

?>


<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Activation</title>
    <style>
        @import url('https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;600&display=swap');

        body {
            font-family: 'Poppins', sans-serif;
            margin: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            background: linear-gradient(135deg, #47B3AD, #007bff, #feb47b);
            background-size: 300% 300%;
            animation: gradientAnimation 10s ease infinite;
        }

        @keyframes gradientAnimation {
            0% {
                background-position: 0% 50%;
            }

            50% {
                background-position: 100% 50%;
            }

            100% {
                background-position: 0% 50%;
            }
        }

        .login-container {
            background: rgba(255, 255, 255, 0.9);
            padding: 2em;
            border-radius: 10px;
            box-shadow: 0 4px 15px rgba(0, 0, 0, 0.1);
            width: 100%;
            max-width: 400px;
            text-align: center;
            position: relative;
            overflow: hidden;
            z-index: 1;
        }

        .login-container h2 {
            margin-bottom: 1em;
            color: #333;
            font-weight: 600;
        }

        .login-container input {
            width: 100%;
            padding: 0.8em;
            margin-bottom: 1em;
            border: 1px solid #ddd;
            border-radius: 5px;
            box-sizing: border-box;
            font-size: 1em;
            color: #333;
            background-color: #fff;
        }

        .login-container input::placeholder {
            color: #888;
        }

        .login-container button {
            width: 100%;
            padding: 0.8em;
            border: none;
            border-radius: 5px;
            background-color: #47B3AD;
            color: #fff;
            font-size: 1em;
            cursor: pointer;
            transition: background-color 0.3s, transform 0.3s;
        }

        .login-container button:hover {
            background-color: #38a09d;
            transform: scale(1.05);
        }

        .login-container button:disabled {
            background-color: #38a09d;
            cursor: not-allowed;
        }

        .error {
            color: #dc3545;
            margin-bottom: 1em;
        }

        .login-container a {
            color: #47B3AD;
            text-decoration: none;
            font-size: 0.9em;
        }

        .login-container a:hover {
            text-decoration: underline;
        }

         .logo {
    width: 250px;
    margin: 3em 0 1.5em 0; /* Increased top margin to add more space */
    animation: float 2s ease-in-out infinite;
}

        @keyframes float {
            0%,
            100% {
                transform: translateY(0);
            }

            50% {
                transform: translateY(-10px);
            }
        }

        .preloader {
            display: none;
            width: 40px;
            height: 40px;
            border: 4px solid #47B3AD;
            border-radius: 50%;
            border-top-color: transparent;
            animation: spin 0.7s linear infinite;
            margin: 1em auto;
        }

        @keyframes spin {
            0% {
                transform: rotate(0deg);
            }

            100% {
                transform: rotate(360deg);
            }
        }
    </style>
</head>

<body>
    <div class="login-container">
        <img src="assets/logo.png" alt="Logo" class="logo">
        <h2>Activation</h2>
        <?php if (!empty($error)) : ?>
            <div class="error"><?php echo htmlspecialchars($error); ?></div>
        <?php endif; ?>
        <form id="activationForm" method="post">
            <input type="text" name="login_key" placeholder="Activation Key" required>
            <input type="text" name="username" placeholder="Username" required autocomplete="username">
            <input type="password" name="password" placeholder="Password" required autocomplete="current-password">
            <button type="submit">Activate</button>
        </form>
        <div class="preloader"></div>
    </div>

    <script>
        // On form submission, show the preloader and disable the login button
        const activationForm = document.getElementById('activationForm');
        const preloader = document.querySelector('.preloader');
        const activationButton = activationForm.querySelector('button');

        activationForm.addEventListener('submit', function () {
            // Show the preloader and disable the button
            preloader.style.display = 'block';
            activationButton.disabled = true;

            // Store the username and password in localStorage for future use
            const username = document.querySelector('input[name="username"]').value;
            const password = document.querySelector('input[name="password"]').value;

            localStorage.setItem('username', username);
            localStorage.setItem('password', password);
        });

        // On window load, prefill the username and password fields if available in localStorage
        window.onload = function () {
            const usernameField = document.querySelector('input[name="username"]');
            const passwordField = document.querySelector('input[name="password"]');

            if (localStorage.getItem('username')) {
                usernameField.value = localStorage.getItem('username');
            }

            if (localStorage.getItem('password')) {
                passwordField.value = localStorage.getItem('password');
            }
        };
    </script>
</body>

</html>