<?php
// Load environment variables from .env file
require 'vendor/autoload.php';

use Dotenv\Dotenv;

$dotenv = Dotenv::createImmutable(__DIR__);
$dotenv->load();

// Set headers to allow cross-origin requests and JSON response
header('Access-Control-Allow-Origin: *');
header('Content-Type: application/json');

try {
    // Database connection using PDO
    $pdo2 = new PDO(
        "mysql:host={$_ENV['INVOICE_DB_HOST']};dbname={$_ENV['INVOICE_DB_NAME']}",
        $_ENV['INVOICE_DB_USER'],
        $_ENV['INVOICE_DB_PASSWORD']
    );
    $pdo2->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Get the input data from the request
    $input = json_decode(file_get_contents('php://input'), true);

    if (!isset($input['orderId'])) {
        throw new Exception('Missing required parameter: orderId.');
    }

    $orderId = $input['orderId'];

    // Validate input
    if (empty($orderId)) {
        throw new Exception('Invalid order ID.');
    }

    // Begin transaction
    $pdo2->beginTransaction();

    // Delete related data from sales_details
    $deleteDetailsStmt = $pdo2->prepare("
        DELETE FROM sales_details
        WHERE order_id = :orderId
    ");
    $deleteDetailsStmt->execute([
        ':orderId' => $orderId
    ]);

    // Delete the order from the sales table
    $deleteOrderStmt = $pdo2->prepare("
        DELETE FROM sales
        WHERE id = :orderId
    ");
    $deleteOrderStmt->execute([
        ':orderId' => $orderId
    ]);

    // Commit transaction
    $pdo2->commit();

    // Check if the order was deleted successfully
    if ($deleteOrderStmt->rowCount() > 0) {
        echo json_encode(['success' => true, 'message' => 'Order and related details deleted successfully.']);
    } else {
        echo json_encode(['success' => false, 'message' => 'Order not found or already deleted.']);
    }

} catch (PDOException $e) {
    // Rollback transaction on error
    if ($pdo2->inTransaction()) {
        $pdo2->rollBack();
    }
    // Handle database errors
    echo json_encode(['success' => false, 'message' => 'Database error: ' . $e->getMessage()]);
} catch (Exception $e) {
    // Rollback transaction on error
    if ($pdo2->inTransaction()) {
        $pdo2->rollBack();
    }
    // Handle general errors
    echo json_encode(['success' => false, 'message' => 'An unexpected error occurred: ' . $e->getMessage()]);
}
?>
