<?php
// Load environment variables from .env file
require 'vendor/autoload.php';

use Dotenv\Dotenv;

$dotenv = Dotenv::createImmutable(__DIR__);
$dotenv->load();

// Set headers to allow cross-origin requests and JSON response
header('Access-Control-Allow-Origin: *');
header('Content-Type: application/json');

try {
    // Database connection using PDO
    $pdo = new PDO(
        "mysql:host={$_ENV['INVOICE_DB_HOST']};dbname={$_ENV['INVOICE_DB_NAME']}",
        $_ENV['INVOICE_DB_USER'],
        $_ENV['INVOICE_DB_PASSWORD']
    );
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Get the order ID from the request
    $orderId = $_GET['id'] ?? '';

    if (empty($orderId)) {
        echo json_encode(['error' => 'Order ID is required']);
        exit;
    }

    // Fetch order information including discount, delivery charge, and total amount
    $orderStmt = $pdo->prepare("
        SELECT id, order_amount, payment_method, payment_status, created_at, order_type, pickup_user, delivery_address, 
               coupon_discount_amount, delivery_charge, total_amount
        FROM sales 
        WHERE id = :orderId
    ");
    $orderStmt->bindParam(':orderId', $orderId, PDO::PARAM_INT);
    $orderStmt->execute();
    $orderInfo = $orderStmt->fetch(PDO::FETCH_ASSOC);

    if (!$orderInfo) {
        echo json_encode(['error' => 'Order not found']);
        exit;
    }

    // Fetch order details
    $detailsStmt = $pdo->prepare("
        SELECT food_id, food_details, quantity, price, variation 
        FROM sales_details 
        WHERE order_id = :orderId
    ");
    $detailsStmt->bindParam(':orderId', $orderId, PDO::PARAM_INT);
    $detailsStmt->execute();
    $orderDetails = $detailsStmt->fetchAll(PDO::FETCH_ASSOC);

    // Process delivery address
    if ($orderInfo['delivery_address']) {
        $orderInfo['delivery_address'] = json_decode($orderInfo['delivery_address'], true);
    }

    // Prepare the response data
    $response = [
        'orderInfo' => $orderInfo,
        'orderDetails' => $orderDetails
    ];

    echo json_encode($response);

} catch (PDOException $e) {
    echo json_encode(['error' => 'Database error: ' . $e->getMessage()]);
} catch (Exception $e) {
    echo json_encode(['error' => 'An unexpected error occurred: ' . $e->getMessage()]);
}
?>
