<?php
// Load environment variables from .env file
require 'vendor/autoload.php';

use Dotenv\Dotenv;

$dotenv = Dotenv::createImmutable(__DIR__);
$dotenv->load();

// Set headers to allow cross-origin requests and JSON response
header('Access-Control-Allow-Origin: *');
header('Content-Type: application/json');

try {
    // Database connection using PDO
    $pdo2 = new PDO(
        "mysql:host={$_ENV['INVOICE_DB_HOST']};dbname={$_ENV['INVOICE_DB_NAME']}",
        $_ENV['INVOICE_DB_USER'],
        $_ENV['INVOICE_DB_PASSWORD']
    );
    $pdo2->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Get the input data from the request
    $input = json_decode(file_get_contents('php://input'), true);

    if (!isset($input['orderId'], $input['paymentStatus'], $input['paymentMethod'])) {
        throw new Exception('Missing required parameters.');
    }

    $orderId = $input['orderId'];
    $paymentStatus = $input['paymentStatus'];
    $paymentMethod = $input['paymentMethod'];

    // Validate input
    if (!in_array($paymentStatus, ['paid', 'unpaid']) || !in_array($paymentMethod, ['cash', 'card'])) {
        throw new Exception('Invalid payment status or payment method.');
    }

    // Update the order in the database
    $updateStmt = $pdo2->prepare("
        UPDATE sales
        SET payment_status = :paymentStatus, payment_method = :paymentMethod
        WHERE id = :orderId
    ");

    $updateStmt->execute([
        ':paymentStatus' => $paymentStatus,
        ':paymentMethod' => $paymentMethod,
        ':orderId' => $orderId
    ]);

    // Check if the order was updated successfully
    if ($updateStmt->rowCount() > 0) {
        echo json_encode(['success' => true, 'message' => 'Order updated successfully.']);
    } else {
        echo json_encode(['success' => false, 'message' => 'Order not found or no change detected.']);
    }

} catch (PDOException $e) {
    // Handle database errors
    echo json_encode(['success' => false, 'message' => 'Database error: ' . $e->getMessage()]);
} catch (Exception $e) {
    // Handle general errors
    echo json_encode(['success' => false, 'message' => 'An unexpected error occurred: ' . $e->getMessage()]);
}
?>
