<?php
// Load environment variables from .env file using a package like vlucas/phpdotenv if needed
require 'vendor/autoload.php';

use Dotenv\Dotenv;

$dotenv = Dotenv::createImmutable(__DIR__);
$dotenv->load();

// Set headers to allow cross-origin requests and JSON response
header('Access-Control-Allow-Origin: *');
header('Content-Type: application/json');

try {
    // Database connection using PDO
    $pdo2 = new PDO(
        "mysql:host={$_ENV['INVOICE_DB_HOST']};dbname={$_ENV['INVOICE_DB_NAME']}",
        $_ENV['INVOICE_DB_USER'],
        $_ENV['INVOICE_DB_PASSWORD']
    );
    $pdo2->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Fetch all unpaid orders from the sales table
    $salesStmt = $pdo2->prepare("
        SELECT id, 
            order_amount, 
            payment_method, 
            payment_status, 
            created_at, 
            delivery_address, 
            coupon_discount_amount, 
            delivery_charge, 
            pickup_user, 
            order_status, 
            order_type 
        FROM sales 
        WHERE payment_status = 'unpaid'
    ");

    $salesStmt->execute();
    $posOrders = $salesStmt->fetchAll(PDO::FETCH_ASSOC);

    // Output the orders as JSON with key 'posOrders'
    echo json_encode(['posOrders' => $posOrders]);

} catch (PDOException $e) {
    // Handle database errors
    echo json_encode(['error' => 'Database error: ' . $e->getMessage()]);
    exit;
} catch (Exception $e) {
    // Handle general errors
    echo json_encode(['error' => 'An unexpected error occurred: ' . $e->getMessage()]);
    exit;
}
?>
