 let productQuantities = {};
        let paymentMethod = null;
        let servingOption = null;
        let discountAmount = 0;
        let deliveryChargeAmount = 0;
        let deliveryAddress = null;

  // Handle product selection and variations
        document.querySelectorAll('.product').forEach(product => {
            product.addEventListener('click', () => {
                const id = product.getAttribute('data-id');
                const name = product.getAttribute('data-name');
                const price = parseFloat(product.getAttribute('data-price'));
                const variations = JSON.parse(product.getAttribute('data-variations'));

                if (variations && variations.length > 0) {
                    showVariationPopup(name, price, variations, id);
                } else {
                    addProductToList(name, price, [], id);
                }
            });
        });

        // Update total and amount to pay
        function updateTotalAndAmountToPay() {
            const subtotal = Object.values(productQuantities).reduce((total, product) => total + (product.price * product.quantity), 0);
            const total = subtotal + deliveryChargeAmount - discountAmount;
            document.getElementById('total-price').textContent = `£${subtotal.toFixed(2)}`;
            document.getElementById('discount-amount').textContent = `£${discountAmount.toFixed(2)}`;
            document.getElementById('delivery-charge-amount').textContent = `£${deliveryChargeAmount.toFixed(2)}`;
            document.getElementById('amount-to-pay').textContent = `£${total.toFixed(2)}`;
        }


//online orders
// URL for fetching online orders
const onlineOrdersApi = '<?php echo $posordersapi; ?>online_orders_api.php';

async function fetchAndDisplayOnlineOrders() {
    try {
        const response = await fetch(onlineOrdersApi);

        if (!response.ok) {
            throw new Error('Network response was not ok ' + response.statusText);
        }

        const data = await response.json();

        const ordersContainer = document.getElementById('online-orders-container');
        ordersContainer.innerHTML = ''; // Clear existing content

        if (!Array.isArray(data.onlineOrders)) {
            throw new Error('Fetched data is not an array');
        }

        data.onlineOrders.forEach(order => {
            const orderBox = document.createElement('div');
            orderBox.classList.add('order-box', order.order_type.toLowerCase());

            // Parse the delivery address if it's in JSON format
            let deliveryAddressHtml = '';
            if (order.delivery_address) {
                try {
                    const address = JSON.parse(order.delivery_address);
                    deliveryAddressHtml = `
                        <div class="delivery-address">
                            ${address.house_number} ${address.street}, ${address.town}, ${address.postcode}
                            <br>Phone: ${order.phone}
                        </div>
                    `;
                } catch (e) {
                    console.error('Error parsing delivery address:', e);
                }
            }

            // Create the main content
            
            // Function to format date in 'YYYY-MM-DD HH:mm:ss' format
function formatDate(dateString) {
    const date = new Date(dateString);
    const year = date.getFullYear();
    const month = String(date.getMonth() + 1).padStart(2, '0');
    const day = String(date.getDate()).padStart(2, '0');
    const hours = String(date.getHours()).padStart(2, '0');
    const minutes = String(date.getMinutes()).padStart(2, '0');
    const seconds = String(date.getSeconds()).padStart(2, '0');
    
    return `${year}-${month}-${day} ${hours}:${minutes}:${seconds}`;
}
          // Extract values and compute the necessary amounts
const totalAmount = parseFloat(order.order_amount) || 0;
const discount = parseFloat(order.coupon_discount_amount) || 0;
const deliveryCharge = parseFloat(order.delivery_charge) || 0;
const orderAmount = (totalAmount + discount - deliveryCharge).toFixed(2);
const orderTime = formatDate(order.created_at); // Format order time
const orderStatus = order.order_status; // Assuming this is a string

const detailsHtml = `
<div class="order-time">Order Time: ${orderTime}</div>
    <div class="order-status">Status: ${orderStatus}</div>
    
    <div class="order-id">Order #${order.id}</div>
    <div class="customer-name">Customer: ${order.f_name} ${order.l_name}</div>

    <div class="total-amount">Total: £${totalAmount}</div>
    
    ${order.order_type === 'Delivery' ? deliveryAddressHtml : ''}
    ${order.order_type === 'Pick-Up' ? `<div class="pickup-user">${order.pickup_user}</div>` : ''}
`;


            // Create the meta section
            const metaHtml = `
                <div class="order-type">Type: ${order.order_type}</div>
                <div class="order-status">Status: ${order.payment_status}</div>
                <div class="order-actions">
                    <button onclick="printOnlineOrder(${order.id})">PRINT</button>
                    <button onclick="showOrderStatusModal(${order.id})">STATUS</button>
                </div>
            `;

            // Set the inner HTML
            orderBox.innerHTML = `
                <div class="order-details">${detailsHtml}</div>
                <div class="order-meta">${metaHtml}</div>
            `;

            ordersContainer.appendChild(orderBox);
        });
    } catch (error) {
        console.error('Error fetching online orders:', error);
    }
}

// Function to print the order using the separate print API
function printOnlineOrder(orderId) {
    fetch(`<?php echo $posordersapi; ?>print_online_order_api.php?id=${orderId}`)
        .then(response => response.json())
        .then(data => {
            if (data.error) {
                console.error('Error fetching order data:', data.error);
                alert('Failed to fetch order data. Please try again.');
                return;
            }

            const orderInfo = data.orderInfo;
            const orderDetails = data.orderDetails;
            const orderVariations = data.orderVariations || []; // Ensure this is an array, even if empty

            const subtotal = orderDetails.reduce((total, item) => {
                const basePrice = parseFloat(item.price) || 0;
                const discount = parseFloat(item.discount_on_food) || 0;
                const priceAfterDiscount = basePrice - discount;
                return total + (priceAfterDiscount * item.quantity);
            }, 0);

            const discountAmount = parseFloat(orderInfo.coupon_discount_amount) || 0;
            const deliveryChargeAmount = parseFloat(orderInfo.delivery_charge) || 0;
            const totalAmount = subtotal - discountAmount + deliveryChargeAmount;

            let deliveryAddressHtml = '';
            if (orderInfo.order_type.toLowerCase() === 'delivery') {
                // Delivery order
                if (orderInfo.delivery_address) {
                    try {
                        const addressData = typeof orderInfo.delivery_address === 'string' ? JSON.parse(orderInfo.delivery_address) : orderInfo.delivery_address;
                        if (addressData) {
                            const contactPersonName = addressData.contact_person_name || 'N/A';
                            const contactPersonNumber = addressData.contact_person_number || 'N/A';
                            const address = addressData.address || 'N/A';
                            deliveryAddressHtml = `
                                <h3>Delivery Address:</h3>
                                
                                    <h5>${address}<br>
                                    Name: ${contactPersonName}<br></h5>
                                    <h3>
                                    Phone: ${contactPersonNumber}
                                </h3>
                            `;
                        } else {
                            deliveryAddressHtml = '<p>Invalid delivery address format.</p>';
                        }
                    } catch (e) {
                        console.error('Error parsing delivery address:', e);
                        deliveryAddressHtml = '<p>Invalid delivery address format.</p>';
                    }
                }
            } else {
                // Non-delivery order
                const customerFirstName = orderInfo.f_name || 'N/A';
                const customerLastName = orderInfo.l_name || 'N/A';
                const customerName = `${customerFirstName} ${customerLastName}`;
                const customerPhone = orderInfo.phone || 'N/A';
                deliveryAddressHtml = `
                    <h3>Customer Details:</h3>
                    <p>
                        Name: ${customerName}<br>
                        Phone: ${customerPhone}
                    </p>
                `;
            }

            const receiptContent = `
                <html>
                <head>
                    <style>
    @media print {
        @page {
            size: 80mm;
            margin: 0;
        }
        body {
            font-family: Arial, sans-serif;
            font-size: 12px;
            width: 80mm;
            margin: 0;
        }
        .receipt {
            width: 80mm;
            padding: 10mm;
            border: 1px solid #ddd;
        }

        /* Existing styles */
        .text-center {
            text-align: center;
        }
        .d-flex {
            display: flex;
            justify-content: space-between;
        }
        .text-right {
            text-align: right;
        }
        .text-muted {
            color: #6c757d;
        }
        .fw-500 {
            font-weight: 500;
        }
        .border-bottom-dashed {
            border-bottom: 1px dashed #979797;
        }
        .mt-1 {
            margin-top: 0.25rem;
        }
        .mb-1 {
            margin-bottom: 0.25rem;
        }
        .initial-38-2 {
            max-width: 100%;
            height: auto;
        }
    }
</style>

                </head>
                <body>
                    <div class="receipt">
                        <div class="text-center pt-3">
                            <img src="<?php echo htmlspecialchars($logourl); ?>" class="initial-38-2" alt="">
                        </div>
                        <div class="text-center pt-3 mb-3">
                            <h5 class="initial-38-3"><?php echo htmlspecialchars($Restaurantname); ?></h5>
                            <h5 class="text-break initial-38-4"><?php echo htmlspecialchars($Restaurantaddress); ?></h5>
                            <h5 class="text-muted">${new Date().toLocaleDateString('en-GB')} ${new Date().toLocaleTimeString('en-GB')}</h5>
                            <h5><span>Phone</span> <span>:</span> <span><?php echo htmlspecialchars($Restaurantphone); ?></span></h5>
                        </div>

                        <h5 class="d-flex">
                            <span>Order Type</span>
                            <span>${orderInfo.order_type}</span>
                        </h5>

                        <div class="border border-dashed border-secondary p-3 rounded">
                            <h5 class="d-flex">
                                <span class="text-muted">Order ID</span>
                                <span>${orderInfo.id}</span>
                            </h5>
                        </div>

                        ${deliveryAddressHtml}

    ${orderInfo.delivery_instruction ? `<p><strong>Delivery Instruction:</strong> ${orderInfo.delivery_instruction}</p>` : ''}

                        <h3>Products:</h3>
                        <ul>
                            ${orderDetails.map((item, index) => {
                                let foodDetails;
                                try {
                                    foodDetails = JSON.parse(item.food_details);
                                } catch (error) {
                                    console.error('Error parsing food details:', error);
                                    foodDetails = { name: 'Unknown Item' }; // Fallback
                                }

                                const itemName = foodDetails.name || 'Unknown Item';

                                // Calculate price after discount
                                const Itemqty = parseFloat(item.quantity) || 0;
                                const basePrice = parseFloat(item.price) || 0;
                                const discount = parseFloat(item.discount_on_food) || 0;
                                const priceAfterDiscount = Itemqty*(basePrice - discount);

                                // Get variations for this item from orderVariations
                                const variations = (orderVariations[index] && Array.isArray(orderVariations[index])) ? orderVariations[index] : [];
                                const itemVariations = variations.length > 0 ? variations.map(variation => `
                                    <div class="variation">
                                        ${variation.name ? `<span>${variation.name}:</span>` : ''}
                                        ${variation.values.map(value => `
                                            <span>${value.label}</span>
                                        `).join(', ')}
                                    </div>
                                `).join('') : ''; // Leave blank if no variations

                                return `
                                    <li>
                                        ${item.quantity} x ${itemName} - £${priceAfterDiscount.toFixed(2)}
                                        ${itemVariations ? `<div>${itemVariations}</div>` : ''} <!-- Only add variations if they exist -->
                                    </li>
                                `;
                            }).join('')}
                        </ul>

                        <div class="border-bottom-dashed mb-3"></div>
                        <div>
                           <div class="px-3">
                    <dl class="row text-right">
                        <dt class="col-6 text-left text-muted">Items Price</dt>
                        <dd class="col-6">£${subtotal.toFixed(2)}</dd>
                        <dd class="col-12 border-bottom-dashed mb-2"></dd>
                        <dt class="col-6 text-left text-muted">Discount</dt>
                        <dd class="col-6">- £${parseFloat(orderInfo.coupon_discount_amount).toFixed(2)}</dd>
                        <dt class="col-6 text-left text-muted">Delivery charge</dt>
                        <dd class="col-6">£${parseFloat(orderInfo.delivery_charge).toFixed(2)}</dd>
                        <dd class="col-12 border-bottom-dashed mb-2"></dd>
                        <dt class="col-6 text-left fw-500 fz-20px">Total</dt>
                        <dd class="col-6 fz-20px fw-500">£${parseFloat(orderInfo.order_amount).toFixed(2)}</dd>
                    </dl>
                </div>
            </div>
<!-- Additional Information Section -->
<div class="px-3 mt-1">
   <dd class="col-12 border-bottom-dashed mb-2"></dd>
    ${orderInfo.order_note ? `<p><strong>Order Note:</strong> ${orderInfo.order_note}</p>` : ''}
    
    ${orderInfo.unavailable_item_note ? `<p><strong>If Item Note:</strong> ${orderInfo.unavailable_item_note}</p>` : ''}
</div>
                        <dd class="col-12 border-bottom-dashed mb-2"></dd>
                        <div class="d-flex flex-row justify-content-between">
                            <span class="text-capitalize d-flex"><span>Paid by</span> <span>:</span> <span>${orderInfo.payment_method}</span></span>
                        </div>
                        <dd class="col-12 border-bottom-dashed my-2"></dd>
                        <h5 class="text-center pt-1 justify-content-center mb-0">
                            <span class="d-block fw-500">THANK YOU</span>
                        </h5>
                        <div class="text-center">For ordering food from <?php echo htmlspecialchars($Restaurantname); ?></div>
                        <dd class="col-12 border-bottom-dashed my-2"></dd>
                        <span class="d-block text-center">© <?php echo date("Y"); ?> <?php echo htmlspecialchars($Restaurantname); ?>. All rights reserved Powered By Foodspot</span>
                    </div>
                </body>
                </html>
            `;

            // Create a hidden iframe for printing
            const iframe = document.createElement('iframe');
            iframe.style.position = 'absolute';
            iframe.style.width = '0';
            iframe.style.height = '0';
            iframe.style.border = 'none';
            document.body.appendChild(iframe);

            const iframeDoc = iframe.contentWindow.document;
            iframeDoc.open();
            iframeDoc.write(receiptContent);
            iframeDoc.close();

            iframe.contentWindow.focus();
            iframe.contentWindow.print();

            // Clean up after printing
            iframe.addEventListener('load', () => {
                iframe.contentWindow.onafterprint = () => {
                    document.body.removeChild(iframe);
                };
            });
        })
        .catch(error => {
            console.error('Error fetching order data:', error);
            alert('Failed to fetch order data. Please try again.');
        });
}

// Initialize fetch and display when the page loads
window.onload = fetchAndDisplayOnlineOrders;








//pos orders 
const posordersapi = '<?php echo $posordersapi; ?>pos_orders_api.php';

async function fetchAndDisplayOrders() {
    try {
        const response = await fetch(posordersapi);

        if (!response.ok) {
            throw new Error('Network response was not ok ' + response.statusText);
        }

        const data = await response.json();

        const ordersContainer = document.getElementById('orders-container');
        ordersContainer.innerHTML = ''; // Clear existing content

        if (!Array.isArray(data.posOrders)) {
            throw new Error('Fetched data is not an array');
        }

        data.posOrders.forEach(order => {
            const orderBox = document.createElement('div');
            orderBox.classList.add('order-box', order.order_type.toLowerCase());

            // Parse the delivery address if it's in JSON format
            let deliveryAddressHtml = '';
            if (order.delivery_address) {
                try {
                    const address = JSON.parse(order.delivery_address);
                    deliveryAddressHtml = `
                        <div class="delivery-address">
                            ${address.house_number} ${address.street}, ${address.town}, ${address.postcode}
                            <br>Phone: ${address.phone}
                        </div>
                    `;
                } catch (e) {
                    console.error('Error parsing delivery address:', e);
                }
            }

            // Create the main content
            function formatDateTime(dateString) {
    const date = new Date(dateString);
    const dateFormatted = date.toLocaleDateString('en-GB'); // 'YYYY-MM-DD' format
    const timeFormatted = date.toLocaleTimeString('en-GB', { hour: '2-digit', minute: '2-digit', second: '2-digit' }); // 'HH:mm:ss' format
    return `${dateFormatted} ${timeFormatted}`;
}

// Extract and format date and time
const orderDateTime = formatDateTime(order.created_at);
            const amount = parseFloat(order.order_amount);
const discount = parseFloat(order.coupon_discount_amount) || 0;
const deliveryCharge = parseFloat(order.delivery_charge) || 0;
const totalAmount = (amount - discount + deliveryCharge).toFixed(2);

const detailsHtml = `
    <div class="order-id">Order #${order.id}</div>

    <div class="total-amount">Total: £${totalAmount}</div>
    ${order.order_type === 'Delivery' ? deliveryAddressHtml : ''}
    ${order.order_type === 'Pick-Up' ? `<div class="pickup-user">${order.pickup_user}</div>` : ''}
`;


            // Create the meta section
            const metaHtml = `
                <div class="order-date">Date: ${orderDateTime}</div>
                <div class="order-type">Type: ${order.order_type}</div>
                <div class="order-actions">
                    
<button onclick="printOrder(${order.id})">PRINT</button>

                    <button onclick="showPaymentModal(${order.id})">DONE</button>
                    <button onclick="showDeleteConfirmModal(${order.id})">X</button>
                </div>
            `;

            // Set the inner HTML
            orderBox.innerHTML = `
                <div class="order-details">${detailsHtml}</div>
                <div class="order-meta">${metaHtml}</div>
            `;

            ordersContainer.appendChild(orderBox);
        });
    } catch (error) {
        console.error('Error fetching orders:', error);
    }
}




function printOrder(orderId) {
    fetch(`<?php echo $posordersapi; ?>print_pos_order_api.php?id=${orderId}`)
        .then(response => response.json())
        .then(data => {
            if (data.error) {
                console.error('Error fetching order data:', data.error);
                alert('Failed to fetch order data. Please try again.');
                return;
            }

            const orderInfo = data.orderInfo;
            const orderDetails = data.orderDetails;

            const subtotal = orderDetails.reduce((total, item) => {
                const itemTotalPrice = parseFloat(item.price) * parseFloat(item.quantity);
                return total + itemTotalPrice;
            }, 0);
            const discountAmount = parseFloat(orderInfo.coupon_discount_amount) || 0;
            const deliveryChargeAmount = parseFloat(orderInfo.delivery_charge) || 0;
            const totalAmount = parseFloat(orderInfo.total_amount) || 0;

            let deliveryAddressHtml = '';
            if (orderInfo.order_type.toLowerCase() === 'delivery' && orderInfo.delivery_address) {
                try {
                    const address = typeof orderInfo.delivery_address === 'string' ? JSON.parse(orderInfo.delivery_address) : orderInfo.delivery_address;
                    if (address && address.contact_person_name && address.contact_person_number && address.address) {
                        deliveryAddressHtml = `
                            <h3>Delivery Address:</h3>
                            <p>
                                ${address.contact_person_name}<br>
                                Phone: ${address.contact_person_number}<br>
                                Address: ${address.address}
                            </p>
                        `;
                    } else {
                        deliveryAddressHtml = '<p>Invalid delivery address format.</p>';
                    }
                } catch (e) {
                    console.error('Error parsing delivery address:', e);
                    deliveryAddressHtml = '<p>Invalid delivery address format.</p>';
                }
            } else if (orderInfo.order_type.toLowerCase() === 'pick-up') {
                deliveryAddressHtml = `
                    <h3>Pick Up By ${orderInfo.f_name} ${orderInfo.l_name}</h3>
                    <p>Phone: ${orderInfo.phone}</p>
                `;
            }

            const receiptContent = `
                <html>
                <head>
                    <style>
                        @media print {
                            @page {
                                size: 80mm;
                                margin: 0;
                            }
                            body {
                                font-family: Arial, sans-serif;
                                font-size: 12px;
                                width: 80mm;
                                margin: 0;
                            }
                            .receipt {
                                width: 80mm;
                                padding: 10mm;
                                border: 1px solid #ddd;
                            }
                            .text-center {
                                text-align: center;
                            }
                            .d-flex {
                                display: flex;
                                justify-content: space-between;
                            }
                            .text-right {
                                text-align: right;
                            }
                            .text-muted {
                                color: #6c757d;
                            }
                            .fw-500 {
                                font-weight: 500;
                            }
                            .border-bottom-dashed {
                                border-bottom: 1px dashed #979797;
                            }
                            .mt-1 {
                                margin-top: 0.25rem;
                            }
                            .mb-1 {
                                margin-bottom: 0.25rem;
                            }
                            .initial-38-2 {
                                max-width: 100%;
                                height: auto;
                            }
                        }
                    </style>
                </head>
                <body>
                    <div class="receipt">
                        <div class="text-center pt-3">
                             <img src="<?php echo htmlspecialchars($logourl); ?>" class="initial-38-2" alt="">
                        </div>
                        <div class="text-center pt-3 mb-3">
                           <h5 class="initial-38-3"><?php echo htmlspecialchars($Restaurantname); ?></h5>
                           <h5 class="text-break initial-38-4"><?php echo htmlspecialchars($Restaurantaddress); ?></h5>
                           <h5 class="text-muted">${new Date().toLocaleDateString('en-GB')} ${new Date().toLocaleTimeString('en-GB')}</h5>
                           <h5><span>Phone</span> <span>:</span> <span><?php echo htmlspecialchars($Restaurantphone); ?></span></h5>
                        </div>

                        <h5 class="d-flex">
                            <span>Order Type</span>
                            <span>${orderInfo.order_type}</span>
                        </h5>

                        <div class="border border-dashed border-secondary p-3 rounded">
                            <h5 class="d-flex">
                                <span class="text-muted">Order ID</span>
                                <span>${orderInfo.id}</span>
                            </h5>
                        </div>

                        ${deliveryAddressHtml}

                        <h3>Products:</h3>
                        <ul>
                            ${orderDetails.map(item => {
                                // Calculate total price for this item
                                const itemTotalPrice = parseFloat(item.quantity) * parseFloat(item.price);
                                return `
                                    <li>
                                        ${item.quantity} x ${item.food_details} - £${itemTotalPrice.toFixed(2)}
                                    </li>
                                `;
                            }).join('')}
                        </ul>

                        <div class="px-3">
                            <dl class="row text-right">
                                <dt class="col-6 text-left text-muted">Items Price</dt>
                                <dd class="col-6">£${subtotal.toFixed(2)}</dd>
                                <dd class="col-12 border-bottom-dashed mb-2"></dd>
                                <dt class="col-6 text-left text-muted">Discount</dt>
                                <dd class="col-6">- £${parseFloat(orderInfo.coupon_discount_amount).toFixed(2)}</dd>
                                <dt class="col-6 text-left text-muted">Delivery charge</dt>
                                <dd class="col-6">£${parseFloat(orderInfo.delivery_charge).toFixed(2)}</dd>
                                <dd class="col-12 border-bottom-dashed mb-2"></dd>
                                <dt class="col-6 text-left fw-500 fz-20px">Total</dt>
                                <dd class="col-6 fz-20px fw-500">£${parseFloat(orderInfo.total_amount).toFixed(2)}</dd>
                            </dl>
                        </div>

                        ${orderInfo.order_note ? `<h5>Order Note:</h5><p>${orderInfo.order_note}</p>` : ''}
                        ${orderInfo.unavailable_item_note ? `<h5>Unavailable Note:</h5><p>${orderInfo.unavailable_item_note}</p>` : ''}
                        ${orderInfo.delivery_instruction ? `<h5>Delivery Instructions:</h5><p>${orderInfo.delivery_instruction}</p>` : ''}
                        
                        <dd class="col-12 border-bottom-dashed my-2"></dd>
                        <h5 class="text-center pt-1 justify-content-center mb-0">
                            <span class="d-block fw-500">THANK YOU</span>
                        </h5>
                        <div class="text-center">For ordering food from <?php echo htmlspecialchars($Restaurantname); ?></div>
                        <dd class="col-12 border-bottom-dashed my-2"></dd>
                        <span class="d-block text-center">© <?php echo date("Y"); ?> <?php echo htmlspecialchars($Restaurantname); ?>. All rights reserved Powered By Foodspot</span>
                    </div>
                </body>
                </html>
            `;

            // Create a hidden iframe for printing
            const iframe = document.createElement('iframe');
            iframe.style.position = 'absolute';
            iframe.style.width = '0';
            iframe.style.height = '0';
            iframe.style.border = 'none';
            document.body.appendChild(iframe);

            const iframeDoc = iframe.contentWindow.document;
            iframeDoc.open();
            iframeDoc.write(receiptContent);
            iframeDoc.close();

            iframe.contentWindow.focus();
            iframe.contentWindow.print();

            // Clean up after printing
            iframe.addEventListener('load', () => {
                iframe.contentWindow.onafterprint = () => {
                    document.body.removeChild(iframe);
                };
            });
        })
        .catch(error => {
            console.error('Error fetching order data:', error);
            alert('Failed to fetch order data. Please try again.');
        });
}






function showPaymentModal(orderId) {
    const modal = document.getElementById('payment-modal');
    modal.style.display = 'block';
    window.currentOrderId = orderId; // Store the order ID for further actions
}

function finishOrder(paymentType) {
    // Logic to update the order's payment status and method
    console.log('Finish order with payment type:', paymentType, 'for order ID:', window.currentOrderId);

    // Example: Update the order status via an API call
    fetch(`<?php echo $posordersapi; ?>update_pos_order_api.php`, {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({
            orderId: window.currentOrderId,
            paymentStatus: 'paid',
            paymentMethod: paymentType
        }),
    })
    .then(response => response.json())
    .then(data => {
        console.log('Order updated:', data);
        // Close the modal
        closeModal('payment-modal');
        // Optionally refresh orders
        fetchAndDisplayOrders();
    })
    .catch(error => console.error('Error updating order:', error));
}

function showDeleteConfirmModal(orderId) {
    const modal = document.getElementById('confirm-delete-modal');
    modal.style.display = 'block';
    window.currentOrderId = orderId; // Store the order ID for further actions
}

function confirmDelete() {
    // Logic to delete the order
    console.log('Delete order:', window.currentOrderId);

    // Example: Delete the order via an API call
    fetch(`<?php echo $posordersapi; ?>delete_pos_order_api.php`, {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({
            orderId: window.currentOrderId
        }),
    })
    .then(response => response.json())
    .then(data => {
        if (data.success) {
            console.log('Order deleted:', data.message);
            // Optionally refresh orders
            fetchAndDisplayOrders();
        } else {
            console.error('Error deleting order:', data.message);
            alert('Error deleting order: ' + data.message);
        }
        // Close the modal
        closeModal('confirm-delete-modal');
    })
    .catch(error => {
        console.error('Error deleting order:', error);
        alert('An error occurred while deleting the order.');
        // Close the modal
        closeModal('confirm-delete-modal');
    });
}

// Example function to open a modal
function openModal(modalId) {
    const modal = document.getElementById(modalId);
    if (modal) {
        modal.style.display = 'block';
    }
}

// Example function to close a modal
function closeModal(modalId) {
    const modal = document.getElementById(modalId);
    if (modal) {
        modal.style.display = 'none';
    }
}

// Function to set the current order ID when opening the delete confirmation modal
function setCurrentOrderId(orderId) {
    window.currentOrderId = orderId;
}


// Call the function when the page loads
fetchAndDisplayOrders();

        
        
        
        
        
        document.querySelectorAll('.category').forEach(category => {
            category.addEventListener('click', () => {
                const selectedCategory = category.getAttribute('data-category');
                document.querySelectorAll('.product').forEach(product => {
                    if (selectedCategory === 'all' || product.getAttribute('data-category') === selectedCategory) {
                        product.style.display = 'block';
                    } else {
                        product.style.display = 'none';
                    }
                });
            });
        });

        document.getElementById('search-input').addEventListener('input', (e) => {
            const searchQuery = e.target.value.toLowerCase();
            document.querySelectorAll('.product').forEach(product => {
                const name = product.getAttribute('data-name').toLowerCase();
                if (name.includes(searchQuery)) {
                    product.style.display = 'block';
                } else {
                    product.style.display = 'none';
                }
            });
        });

        document.getElementById('cash-btn').addEventListener('click', () => {
            paymentMethod = 'cash';
            document.getElementById('cash-btn').classList.add('selected');
            document.getElementById('card-btn').classList.remove('selected');
        });

        document.getElementById('card-btn').addEventListener('click', () => {
            paymentMethod = 'card';
            document.getElementById('card-btn').classList.add('selected');
            document.getElementById('cash-btn').classList.remove('selected');
        });

        document.getElementById('eat-in-btn').addEventListener('click', () => {
            servingOption = 'Eat-In';
            setServingOption('eat-in-btn');
        });

        document.getElementById('take-away-btn').addEventListener('click', () => {
            servingOption = 'Take-Away';
            setServingOption('take-away-btn');
        });

// Function to clear Delivery Address
function clearDeliveryAddress() {
    // Clear the delivery address text
    document.getElementById('delivery-address-text').textContent = '';

    // Hide the delivery address container
    document.getElementById('delivery-address-container').style.display = 'none';

    // Clear the input fields in the delivery address popup
    document.getElementById('house-number').value = '';
    document.getElementById('street').value = '';
    document.getElementById('town').value = '';
    document.getElementById('postcode').value = '';
    document.getElementById('phone').value = '';
}

// Function to set Serving Option and update UI
function setServingOption(optionId) {
    // Logic to handle the UI update based on the selected serving option
    // Add/remove classes or update display here
    document.querySelectorAll('.serving-option button').forEach(button => {
        button.classList.remove('active');
    });
    document.getElementById(optionId).classList.add('active');
}

// Event listener for Delivery button
document.getElementById('delivery-btn').addEventListener('click', () => {
    servingOption = 'Delivery';
    setServingOption('delivery-btn');
    document.getElementById('delivery-address-popup').style.display = 'flex';
});

// Event listener for Eat-In button
document.getElementById('eat-in-btn').addEventListener('click', () => {
    servingOption = 'Eat-In';
    setServingOption('eat-in-btn');
    clearDeliveryAddress();  // Clear delivery address when switching to Eat-In
    clearPickupName();       // Assuming you have a clearPickupName function similar to clearDeliveryAddress
});

// Event listener for Take-Away button
document.getElementById('take-away-btn').addEventListener('click', () => {
    servingOption = 'Take-Away';
    setServingOption('take-away-btn');
    clearDeliveryAddress();  // Clear delivery address when switching to Take-Away
    clearPickupName();       // Assuming you have a clearPickupName function similar to clearDeliveryAddress
});

// Event listener for Pick Up button
document.getElementById('pick-up-btn').addEventListener('click', () => {
    servingOption = 'Pick-Up';
    setServingOption('pick-up-btn');
    clearDeliveryAddress();  // Clear delivery address when switching to Pick Up
    document.getElementById('pick-up-popup').style.display = 'flex';
});

// Close delivery address popup
document.getElementById('close-address-popup').addEventListener('click', () => {
    document.getElementById('delivery-address-popup').style.display = 'none';
});

// Handle delivery address form submission
document.getElementById('delivery-address-form').addEventListener('submit', (e) => {
    e.preventDefault();
    
    // Collect delivery address data
    deliveryAddress = {
        house_number: document.getElementById('house-number').value,
        street: document.getElementById('street').value,
        town: document.getElementById('town').value,
        postcode: document.getElementById('postcode').value,
        phone: document.getElementById('phone').value,
    };

    // Update delivery address display
    updateDeliveryAddressDisplay();

    // Close popup
    document.getElementById('delivery-address-popup').style.display = 'none';
});

// Function to update delivery address display
function updateDeliveryAddressDisplay() {
    if (deliveryAddress) {
        var addressText = `${deliveryAddress.house_number}, ${deliveryAddress.street}, ${deliveryAddress.town}, ${deliveryAddress.postcode} (${deliveryAddress.phone})`;
        document.getElementById('delivery-address-text').textContent = addressText;
        document.getElementById('delivery-address-container').style.display = 'block';
    }
}

// Example function to clear Pickup Name
function clearPickupName() {
    document.getElementById('pickup-name-text').textContent = '';
    document.getElementById('pickup-name-container').style.display = 'none';
    document.getElementById('customer-name').value = '';
}

// Set serving option as selected
function setServingOption(selectedId) {
    document.querySelectorAll('#eat-in-btn, #take-away-btn, #delivery-btn, #pick-up-btn').forEach(btn => {
        btn.classList.remove('selected');
    });
    document.getElementById(selectedId).classList.add('selected');
}

// Save order with or without printing receipt
document.getElementById('save-print-button').addEventListener('click', () => {
    saveOrder(true);
});

document.getElementById('save-button').addEventListener('click', () => {
    saveOrder(false);
});



function saveOrder(printReceipt) {
    // Validation
    if (!paymentMethod) return alert('Please select a payment method.');
    if (!servingOption) return alert('Please select a serving option.');

    // Collect selected items
    const selectedItems = Object.entries(productQuantities).map(([key, product]) => ({
        id: product.id,
        name: product.name,
        price: product.price,
        quantity: product.quantity,
        variations: product.variations
    }));

    if (selectedItems.length === 0) return alert('No products selected.');

    // Prepare request data
    const subtotal = selectedItems.reduce((sum, item) => sum + (item.price * item.quantity), 0);
    const requestData = {
        paymentMethod,
        servingOption,
        products: selectedItems,
        coupon_discount_amount: discountAmount,
        delivery_charge: deliveryChargeAmount,
        total_amount: subtotal + deliveryChargeAmount - discountAmount,
        pickupName: servingOption === 'Pick-Up' ? pickupName : null,
        deliveryAddress: servingOption === 'Delivery' ? deliveryAddress : null
    };

    // Send request
    fetch('save_order.php', {
        method: 'POST',
        headers: { 'Content-Type': 'application/json' },
        body: JSON.stringify(requestData)
    })
    .then(response => response.json())
    .then(data => {
        if (data.success) {
            if (printReceipt) generateAndPrintReceipt(data.invoiceNumber);
            window.location.reload();
        } else {
            alert('Failed to save order.');
        }
    })
    .catch(error => {
        console.error('Error:', error);
        alert('An error occurred while saving the order.');
    });
}






function generateAndPrintReceipt(invoiceNumber) {
    // Calculate subtotal
    const subtotal = Object.values(productQuantities).reduce((total, product) => 
        total + (product.price * product.quantity), 0);

    // Format the delivery address if serving option is delivery
    let deliveryAddressHtml = '';
    if (servingOption.toLowerCase() === 'delivery' && deliveryAddress) {
        deliveryAddressHtml = `
            <h3>Delivery Address:</h3>
            <p>
                ${deliveryAddress.house_number}, ${deliveryAddress.street}, ${deliveryAddress.town}, ${deliveryAddress.postcode}<br>
                Phone: ${deliveryAddress.phone}
            </p>
        `;
    }

    // Format the pickup name if serving option is pick-up
    let pickupNameHtml = '';
    if (servingOption.toLowerCase() === 'pick-up' && pickupName) {
        pickupNameHtml = `
            <h3>Pick Up By ${pickupName}</h3>
        `;
    }

    // Format the receipt content
    const receiptContent = `
        <html>
        <head>
            <style>
                @media print {
                    @page {
                        size: 80mm;
                        margin: 0;
                    }
                    body {
                        font-family: Arial, sans-serif;
                        font-size: 12px;
                        width: 80mm;
                        margin: 0;
                    }
                    .receipt {
                        width: 80mm;
                        padding: 10mm;
                        border: 1px solid #ddd;
                    }
                    .text-center {
                        text-align: center;
                    }
                    .d-flex {
                        display: flex;
                        justify-content: space-between;
                    }
                    .text-right {
                        text-align: right;
                    }
                    .text-muted {
                        color: #6c757d;
                    }
                    .fw-500 {
                        font-weight: 500;
                    }
                    .border-bottom-dashed {
                        border-bottom: 1px dashed #979797;
                    }
                    .mt-1 {
                        margin-top: 0.25rem;
                    }
                    .mb-1 {
                        margin-bottom: 0.25rem;
                    }
                    .initial-38-2 {
                        max-width: 100%;
                        height: auto;
                    }
                }
            </style>
        </head>
        <body>
            <div class="receipt">
                <div class="text-center pt-3">
                    <img src="<?php echo htmlspecialchars($logourl); ?>" class="initial-38-2" alt="">
                </div>
                <div class="text-center pt-3 mb-3">
                    <h5 class="initial-38-3"><?php echo htmlspecialchars($Restaurantname); ?></h5>
                    <h5 class="text-break initial-38-4"><?php echo htmlspecialchars($Restaurantaddress); ?></h5>
                    <h5 class="text-muted">${new Date().toLocaleDateString('en-GB')} ${new Date().toLocaleTimeString('en-GB')}</h5>
                    <h5><span>Phone</span> <span>:</span> <span><?php echo htmlspecialchars($Restaurantphone); ?></span></h5>
                </div>

                <h5 class="d-flex">
                    <span>Order Type</span>
                    <span>${servingOption}</span>
                </h5>

                <div class="border border-dashed border-secondary p-3 rounded">
                    <h5 class="d-flex">
                        <span class="text-muted">Order ID</span>
                        <span>${invoiceNumber}</span>
                    </h5>
                </div>

                ${deliveryAddressHtml}
                ${pickupNameHtml}
                <h3>Products:</h3>
                <ul>
                    ${Object.values(productQuantities).map(product => {
                        // Calculate total price for this item
                        const itemTotalPrice = (product.price * product.quantity).toFixed(2);
                        return `
                            <li>${product.quantity} x ${product.name} - £${itemTotalPrice}</li>
                        `;
                    }).join('')}
                </ul>
                
                <div class="border-bottom-dashed mb-3"></div>
                <div>
                    <div class="px-3">
                        <dl class="row text-right">
                            <dt class="col-6 text-left text-muted">Items Price</dt>
                            <dd class="col-6">£${subtotal.toFixed(2)}</dd>
                            <dd class="col-12 border-bottom-dashed mb-2"></dd>
                            <dt class="col-6 text-left text-muted">Discount</dt>
                            <dd class="col-6">- £${discountAmount.toFixed(2)}</dd>
                            <dt class="col-6 text-left text-muted">Delivery charge</dt>
                            <dd class="col-6">£${deliveryChargeAmount.toFixed(2)}</dd>
                            <dd class="col-12 border-bottom-dashed mb-2"></dd>
                            <dt class="col-6 text-left fw-500 fz-20px">Total</dt>
                            <dd class="col-6 fz-20px fw-500">£${(subtotal + deliveryChargeAmount - discountAmount).toFixed(2)}</dd>
                        </dl>
                    </div>
                </div>

                <dd class="col-12 border-bottom-dashed mb-2"></dd>
                <div class="d-flex flex-row justify-content-between">
                    <span class="text-capitalize d-flex"><span>Paid by</span> <span>:</span> <span>${paymentMethod}</span></span>
                </div>
                <dd class="col-12 border-bottom-dashed my-2"></dd>
                <h5 class="text-center pt-1 justify-content-center mb-0">
                    <span class="d-block fw-500">THANK YOU</span>
                </h5>
                <div class="text-center">For ordering food from <?php echo htmlspecialchars($Restaurantname); ?></div>
                <dd class="col-12 border-bottom-dashed my-2"></dd>
                <span class="d-block text-center">© <?php echo date("Y"); ?> <?php echo htmlspecialchars($Restaurantname); ?>. All rights reserved Powered By Foodspot</span>
            </div>
        </body>
        </html>
    `;

    // Create a hidden iframe for printing
    const iframe = document.createElement('iframe');
    iframe.style.position = 'absolute';
    iframe.style.width = '0';
    iframe.style.height = '0';
    iframe.style.border = 'none';
    document.body.appendChild(iframe);

    const iframeDoc = iframe.contentWindow.document;
    iframeDoc.open();
    iframeDoc.write(receiptContent);
    iframeDoc.close();

    iframe.contentWindow.focus();
    iframe.contentWindow.print();

    // Clean up after printing
    iframe.addEventListener('load', () => {
        iframe.contentWindow.onafterprint = () => {
            document.body.removeChild(iframe);
        };
    });
}







// Function to remove product from the cart list
function removeProductFromList(key) {
    if (productQuantities[key].quantity > 1) {
        productQuantities[key].quantity -= 1;
    } else {
        delete productQuantities[key];
    }

    updateProductList();
}
       // Function to add product to the cart list
function addProductToList(name, price, variations = [], id) {
            const selectedProducts = document.getElementById('selected-products');
            const productKey = `${id}|${name}|${price}`;

            if (productQuantities[productKey]) {
                productQuantities[productKey].quantity += 1;
            } else {
                productQuantities[productKey] = { id: id, name: name, price: price, quantity: 1, variations: variations };
            }

            updateProductList();
            updateTotalAndAmountToPay();
        }


 // Function to update the cart list
function updateProductList() {
    const selectedProducts = document.getElementById('selected-products');
    const totalPriceElem = document.getElementById('total-price');
    selectedProducts.innerHTML = ''; // Clear the list before re-rendering
    let newTotal = 0;

    // Iterate over productQuantities using the updated key format
    for (const [key, product] of Object.entries(productQuantities)) {
        const listItem = document.createElement('li');
        listItem.classList.add('product-item');

        // Product details
        const productDetails = document.createElement('div');
        productDetails.classList.add('product-details');
        productDetails.innerHTML = `
            <div class="product-name">
                <strong>${product.quantity} x ${product.name}</strong>
            </div>
            <div class="price">£${product.price.toFixed(2)}</div>
        `;

        // Variations details
        let variationsHtml = '';
        if (product.variations && product.variations.length > 0) {
            product.variations.forEach(variation => {
                variationsHtml += `<div class="variation">${variation.name}: ${variation.selected ? variation.selected.join(', ') : 'None'}</div>`;
            });
        }

        const variationsContainer = document.createElement('div');
        variationsContainer.classList.add('product-variations');
        variationsContainer.innerHTML = variationsHtml;

        // Remove button
        const removeButton = document.createElement('button');
        removeButton.classList.add('remove-btn');
        removeButton.textContent = 'X';
        removeButton.setAttribute('data-key', key);
        removeButton.addEventListener('click', (e) => {
            const key = e.target.getAttribute('data-key');
            removeProductFromList(key);
        });

        // Append to list item
        listItem.appendChild(productDetails);
        listItem.appendChild(variationsContainer);
        listItem.appendChild(removeButton);

        selectedProducts.appendChild(listItem);
        newTotal += product.price * product.quantity;
    }

    totalPriceElem.textContent = `£${newTotal.toFixed(2)}`;
}

// Open discount popup
        document.getElementById('discount-btn').addEventListener('click', () => {
            document.getElementById('discount-popup').style.display = 'block';
        });

        // Close discount popup
        document.getElementById('close-discount-popup').addEventListener('click', () => {
            document.getElementById('discount-popup').style.display = 'none';
        });

        // Save discount amount
        document.getElementById('discount-form').addEventListener('submit', (e) => {
            e.preventDefault();
            discountAmount = parseFloat(document.getElementById('discount-amount-input').value) || 0;
            document.getElementById('discount-container').style.display = 'block';
            updateTotalAndAmountToPay();
            document.getElementById('discount-popup').style.display = 'none';
        });

        // Open delivery charge popup
        document.getElementById('delivery-charge-btn').addEventListener('click', () => {
            document.getElementById('delivery-charge-popup').style.display = 'block';
        });

        // Close delivery charge popup
        document.getElementById('close-delivery-charge-popup').addEventListener('click', () => {
            document.getElementById('delivery-charge-popup').style.display = 'none';
        });

        // Save delivery charge amount
        document.getElementById('delivery-charge-form').addEventListener('submit', (e) => {
            e.preventDefault();
            deliveryChargeAmount = parseFloat(document.getElementById('delivery-charge-input').value) || 0;
            document.getElementById('delivery-charge-container').style.display = 'block';
            updateTotalAndAmountToPay();
            document.getElementById('delivery-charge-popup').style.display = 'none';
        });

        

  // JavaScript to handle the popups

// Function to clear the Pickup Name
function clearPickupName() {
    // Clear the pickup name text
    document.getElementById('pickup-name-text').textContent = '';

    // Hide the pickup name container
    document.getElementById('pickup-name-container').style.display = 'none';

    // Clear the input field in the pickup name popup (optional)
    document.getElementById('customer-name').value = '';
}

// Event listener for Eat-In button
document.getElementById('eat-in-btn').addEventListener('click', function() {
    clearPickupName();
    // You can add more logic for Eat-In option if needed
});

// Event listener for Take-Away button
document.getElementById('take-away-btn').addEventListener('click', function() {
    clearPickupName();
    // You can add more logic for Take-Away option if needed
});

// Event listener for Delivery button
document.getElementById('delivery-btn').addEventListener('click', function() {
    clearPickupName();
    // You can add more logic for Delivery option if needed
});

// Existing Event listener for Pick Up button
document.getElementById('pick-up-btn').addEventListener('click', function() {
    document.getElementById('pick-up-popup').style.display = 'block';
});

// Close the Pick Up name popup
document.getElementById('close-pick-up-popup').addEventListener('click', function() {
    document.getElementById('pick-up-popup').style.display = 'none';
});

// Handle the Pick Up name form submission
var pickupName; // Define this outside the function

document.getElementById('pick-up-form').addEventListener('submit', function(event) {
    event.preventDefault(); // Prevent the form from submitting

    var customerName = document.getElementById('customer-name').value;

    if (customerName.trim() !== "") {
        // Display the Pickup Name in the invoice view
        document.getElementById('pickup-name-text').textContent = customerName;
        document.getElementById('pickup-name-container').style.display = 'block';

        // Save the pickup name for later use in the invoice
        pickupName = customerName; // Store the customer name

        // Close the Pick Up name popup
        document.getElementById('pick-up-popup').style.display = 'none';
    } else {
        alert("Please enter a name for pickup.");
    }
});



// Optional: Handle the edit button for Pickup Name
document.getElementById('edit-pickup-name-btn').addEventListener('click', function() {
    document.getElementById('pick-up-popup').style.display = 'block';
});

function updateDeliveryAddressDisplay() {
    const addressContainer = document.getElementById('delivery-address-container');
    const addressText = document.getElementById('delivery-address-text');
    const editAddressBtn = document.getElementById('edit-address-btn');
    
    if (deliveryAddress) {
        addressContainer.style.display = 'block';
        addressText.innerHTML = `
            ${deliveryAddress.house_number}, ${deliveryAddress.street}, ${deliveryAddress.town}, ${deliveryAddress.postcode}<br>
            Phone: ${deliveryAddress.phone}
        `;
    } else {
        addressContainer.style.display = 'none';
    }
}

// Handle edit address button click
document.getElementById('edit-address-btn').addEventListener('click', () => {
    document.getElementById('delivery-address-popup').style.display = 'flex';
});

// Show variation popup
        function showVariationPopup(name, price, variations, id) {
            const popup = document.getElementById('variation-popup');
            const variationOptions = document.getElementById('variation-options');
            variationOptions.innerHTML = '';

            variations.forEach((variation, index) => {
                const li = document.createElement('li');
                const title = document.createElement('h3');
                title.textContent = variation.name;
                li.appendChild(title);

                variation.values.forEach(value => {
                    const button = document.createElement('div');
                    button.classList.add('option-button');
                    button.textContent = `${value.label} - £${parseFloat(value.optionPrice).toFixed(2)}`;
                    button.dataset.optionPrice = value.optionPrice;
                    button.dataset.groupIndex = index;
                    button.dataset.value = value.label;

                    button.addEventListener('click', () => {
                        const groupButtons = document.querySelectorAll(`[data-group-index="${index}"]`);
                        if (variation.type === 'single') {
                            groupButtons.forEach(btn => btn.classList.remove('selected'));
                        } else if (variation.type === 'multi') {
                            const selectedButtons = document.querySelectorAll(`[data-group-index="${index}"].selected`);
                            const min = parseInt(button.parentNode.dataset.min, 10);
                            const max = parseInt(button.parentNode.dataset.max, 10);

                            if (selectedButtons.length >= max && !button.classList.contains('selected')) {
                                alert(`You can only select up to ${max} options for ${variation.name}.`);
                                return;
                            }
                        }
                        button.classList.toggle('selected');
                    });

                    li.appendChild(button);
                });

                li.dataset.required = variation.required === 'on' ? 'true' : 'false';
                li.dataset.min = variation.min;
                li.dataset.max = variation.max;
                li.dataset.groupIndex = index;
                li.dataset.type = variation.type;

                variationOptions.appendChild(li);
            });

            document.getElementById('add-variation').onclick = () => {
                const selectedOptions = document.querySelectorAll('.option-button.selected');
                let valid = true;

                document.querySelectorAll('#variation-options > li').forEach(group => {
                    const groupIndex = group.dataset.groupIndex;
                    const min = parseInt(group.dataset.min, 10);
                    const max = parseInt(group.dataset.max, 10);
                    const type = group.dataset.type;
                    const selectedCount = document.querySelectorAll(`[data-group-index="${groupIndex}"].selected`).length;

                    if (group.dataset.required === 'true') {
                        if (type === 'single' && selectedCount !== 1) {
                            valid = false;
                            alert(`Please select exactly 1 option for ${group.querySelector('h3').textContent}.`);
                        } else if (type === 'multi' && (selectedCount < min || selectedCount > max)) {
                            valid = false;
                            alert(`Please select between ${min} and ${max} options for ${group.querySelector('h3').textContent}.`);
                        }
                    }
                });

                if (valid) {
                    const optionPrices = Array.from(selectedOptions).reduce((acc, option) => acc + parseFloat(option.dataset.optionPrice), 0);
                    const variationText = Array.from(selectedOptions).map(btn => btn.textContent).join(', ');
                    const totalPrice = price + optionPrices;

                    addProductToList(name + ' - ' + variationText, totalPrice, [], id);
                    popup.style.display = 'none';
                }
            };

            document.getElementById('close-popup').addEventListener('click', () => {
                popup.style.display = 'none';
            });

            popup.style.display = 'block';
        }


document.addEventListener('DOMContentLoaded', function() {
    const invoiceViewBtn = document.getElementById('invoice-view-btn');
    const onlineViewBtn = document.getElementById('online-view-btn');
    const posOrdersViewBtn = document.getElementById('pos-orders-view-btn');
    
    const invoiceView = document.getElementById('invoice-view');
    const onlineView = document.getElementById('online-view');
    const posOrdersView = document.getElementById('pos-orders-view');
    const productList = document.querySelector('.product-list'); // Assuming this is where products are added

    // Function to show the selected view and hide others
    function showView(viewToShow, btnToActivate) {
        invoiceView.classList.remove('active');
        onlineView.classList.remove('active');
        posOrdersView.classList.remove('active');

        viewToShow.classList.add('active');
        
        // Remove active class from all buttons
    invoiceViewBtn.classList.remove('active-btn');
    onlineViewBtn.classList.remove('active-btn');
    posOrdersViewBtn.classList.remove('active-btn');

    // Add active class to the clicked button
    btnToActivate.classList.add('active-btn');
    }

    // Event listener for Invoice View button
    invoiceViewBtn.addEventListener('click', function() {
        showView(invoiceView, invoiceViewBtn);
    });

    // Event listener for Online View button
    onlineViewBtn.addEventListener('click', function() {
        showView(onlineView, onlineViewBtn);
    });

    // Event listener for POS Orders View button
    posOrdersViewBtn.addEventListener('click', function() {
        showView(posOrdersView, posOrdersViewBtn);
    });

    // Payment method selection
    function selectPaymentMethod(selectedButtonId) {
        var paymentButtons = document.querySelectorAll('.payment-btn');
        paymentButtons.forEach(function(button) {
            if (button.id === selectedButtonId) {
                button.classList.add('active');
            } else {
                button.classList.remove('active');
            }
        });
    }

    // Default selection
    selectPaymentMethod('card-btn');

    // Event listeners for payment buttons
    document.getElementById('cash-btn').addEventListener('click', function() {
        selectPaymentMethod('cash-btn');
    });

    document.getElementById('card-btn').addEventListener('click', function() {
        selectPaymentMethod('card-btn');
    });

    
});
