<?php
require __DIR__ . '/vendor/autoload.php';
require __DIR__ . '/db.php'; // Include the database connection file

use Dotenv\Dotenv;

$dotenv = Dotenv::createImmutable(__DIR__);
$dotenv->load();

session_start();

$error = '';

$db = getInvoiceDbConnection();

// Check if there is any data in the login_key table
$stmt = $db->query("SELECT COUNT(*) FROM login_key");
$rowCount = $stmt->fetchColumn();

if ($rowCount == 0) {
    // No data in the login_key table, redirect to activation page
    header('Location: activation.php');
    exit();
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $username = $_POST['username'] ?? '';
    $password = $_POST['password'] ?? '';

    // Check the login details against the login_key table
    $stmt = $db->prepare("SELECT * FROM login_key WHERE user = :user");
    $stmt->bindParam(':user', $username);
    $stmt->execute();
    $row = $stmt->fetch();

    if ($row && password_verify($password, $row['pass'])) {
        // Password is correct, retrieve the login_key (activation ID)
        $loginKey = $row['login_key'];

        // Initialize cURL session
        $ch = curl_init();
        $apiUrl = $_ENV['API_URL'] . "key_check.php?login_key=" . urlencode($loginKey);

        // Set cURL options
        curl_setopt($ch, CURLOPT_URL, $apiUrl);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_TIMEOUT, 10); // Timeout in seconds
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false); // Skip SSL verification (if necessary)

        // Execute cURL request
        $response = curl_exec($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        $curlError = curl_error($ch);
        curl_close($ch);

        // Determine if there was a cURL error or the HTTP status code is not OK
        if ($curlError || $httpCode != 200) {
            // Log the error if necessary for debugging
            // error_log("cURL Error: $curlError, HTTP Code: $httpCode");

            // Assume login success if API is not reachable or has issues
            $_SESSION['loggedin'] = true;
            header('Location: index.php');
            exit();
        }

        // Process the API response
        $data = json_decode($response, true);

        // Check for specific API error messages
        if (isset($data['error']) && strpos($data['error'], 'Database connection failed') !== false) {
            // Log the error if necessary for debugging
            // error_log("API Error: " . $data['error']);

            // Skip API verification and assume login success if database connection fails
            $_SESSION['loggedin'] = true;
            header('Location: index.php');
            exit();
        }

        // Check API response status
        if (isset($data['status']) && $data['status'] == 1) {
            // If status is 1, set session and redirect to index
            $_SESSION['loggedin'] = true;
            header('Location: index.php');
            exit();
        } else {
            // API response is not valid, truncate the table
            $db->exec("TRUNCATE TABLE login_key");
            header('Location: activation.php');
            exit();
        }
    } else {
        $error = 'Invalid username or password.';
    }
}
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Login</title>
    <style>
        @import url('https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;600&display=swap');

        body {
            font-family: 'Poppins', sans-serif;
            margin: 0;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            background: linear-gradient(135deg, #47B3AD, #007bff, #feb47b);
            background-size: 300% 300%;
            animation: gradientAnimation 10s ease infinite;
        }

        @keyframes gradientAnimation {
            0% {
                background-position: 0% 50%;
            }

            50% {
                background-position: 100% 50%;
            }

            100% {
                background-position: 0% 50%;
            }
        }

        .login-container {
            background: rgba(255, 255, 255, 0.9);
            padding: 2em;
            border-radius: 10px;
            box-shadow: 0 4px 15px rgba(0, 0, 0, 0.1);
            width: 100%;
            max-width: 400px;
            text-align: center;
            position: relative;
            overflow: hidden;
            z-index: 1;
        }

        .login-container h2 {
            margin-bottom: 1em;
            color: #333;
            font-weight: 600;
        }

        .login-container input {
            width: 100%;
            padding: 0.8em;
            margin-bottom: 1em;
            border: 1px solid #ddd;
            border-radius: 5px;
            box-sizing: border-box;
            font-size: 1em;
            color: #333;
            background-color: #fff;
        }

        .login-container input::placeholder {
            color: #888;
        }

        .login-container button {
            width: 100%;
            padding: 0.8em;
            border: none;
            border-radius: 5px;
            background-color: #47B3AD;
            color: #fff;
            font-size: 1em;
            cursor: pointer;
            transition: background-color 0.3s, transform 0.3s;
        }

        .login-container button:hover {
            background-color: #38a09d;
            transform: scale(1.05);
        }

        .login-container button:disabled {
            background-color: #38a09d;
            cursor: not-allowed;
        }

        .error {
            color: #dc3545;
            margin-bottom: 1em;
        }

        .login-container a {
            color: #47B3AD;
            text-decoration: none;
            font-size: 0.9em;
        }

        .login-container a:hover {
            text-decoration: underline;
        }

       .logo {
    width: 250px;
    margin: 3em 0 1.5em 0; /* Increased top margin to add more space */
    animation: float 2s ease-in-out infinite;
}

        @keyframes float {
            0%,
            100% {
                transform: translateY(0);
            }

            50% {
                transform: translateY(-10px);
            }
        }

        .preloader {
            display: none;
            width: 40px;
            height: 40px;
            border: 4px solid #47B3AD;
            border-radius: 50%;
            border-top-color: transparent;
            animation: spin 0.7s linear infinite;
            margin: 1em auto;
        }

        @keyframes spin {
            0% {
                transform: rotate(0deg);
            }

            100% {
                transform: rotate(360deg);
            }
        }
    </style>
</head>

<body>
    <div class="login-container">
        <img src="assets/logo.png" alt="Logo" class="logo">
        <h2>Login</h2>
        <?php if (!empty($error)) : ?>
            <div class="error"><?php echo htmlspecialchars($error); ?></div>
        <?php endif; ?>
        <form id="loginForm" method="post">
            <input type="text" name="username" placeholder="Username" required autocomplete="username">
            <input type="password" name="password" placeholder="Password" required autocomplete="current-password">
            <button type="submit">Login</button>
        </form>
        <div class="preloader"></div>
        <p>Don't have an account? <a href="#">Register</a></p>
    </div>

    <script>
        // On form submission, show the preloader and disable the login button
        const loginForm = document.getElementById('loginForm');
        const preloader = document.querySelector('.preloader');
        const loginButton = loginForm.querySelector('button');

        loginForm.addEventListener('submit', function () {
            // Show the preloader and disable the button
            preloader.style.display = 'block';
            loginButton.disabled = true;

            // Store the username and password in localStorage for future use
            const username = document.querySelector('input[name="username"]').value;
            const password = document.querySelector('input[name="password"]').value;

            localStorage.setItem('username', username);
            localStorage.setItem('password', password);
        });

        // On window load, prefill the username and password fields if available in localStorage
        window.onload = function () {
            const usernameField = document.querySelector('input[name="username"]');
            const passwordField = document.querySelector('input[name="password"]');

            if (localStorage.getItem('username')) {
                usernameField.value = localStorage.getItem('username');
            }

            if (localStorage.getItem('password')) {
                passwordField.value = localStorage.getItem('password');
            }
        };
    </script>
</body>

</html>
