<?php
require __DIR__ . '/vendor/autoload.php';  // Ensure this path is correct
require('fpdf/fpdf.php');

use Dotenv\Dotenv;

$dotenv = Dotenv::createImmutable(__DIR__);
$dotenv->load();

try {
    // Database connection for printing receipt
    $pdo = new PDO(
        "mysql:host={$_ENV['INVOICE_DB_HOST']};dbname={$_ENV['INVOICE_DB_NAME']}",
        $_ENV['INVOICE_DB_USER'],
        $_ENV['INVOICE_DB_PASSWORD']
    );
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Fetch the order data
    $orderId = isset($_GET['order_id']) ? (int)$_GET['order_id'] : 0;

    if ($orderId > 0) {
        // Fetch order details
        $stmt = $pdo->prepare("
            SELECT 
                s.id AS invoice_number, 
                s.order_amount, 
                s.payment_method, 
                s.transaction_reference AS serving_option, 
                sd.food_details, 
                sd.quantity, 
                sd.price 
            FROM sales s
            JOIN sales_details sd ON s.id = sd.order_id
            WHERE s.id = :order_id
        ");
        $stmt->execute(['order_id' => $orderId]);
        $order = $stmt->fetchAll(PDO::FETCH_ASSOC);

        if ($order) {
            // Create a new PDF document with 80mm width
            $pdf = new FPDF('P', 'mm', array(80, 297)); // Page size: 80mm x 297mm (A4 height)
            $pdf->AddPage();
            $pdf->SetFont('Arial', 'B', 10);

            // Title
            $pdf->Cell(0, 10, 'COCOEATZ', 0, 1, 'C');
            $pdf->SetFont('Arial', '', 8);
            $pdf->Ln(5);

            // Invoice Number
            $pdf->Cell(0, 10, 'Invoice No: #' . $order[0]['invoice_number'], 0, 1);
            $pdf->Cell(0, 10, 'Payment Method: ' . ucfirst($order[0]['payment_method']), 0, 1);
            $pdf->Cell(0, 10, 'Serving Option: ' . ucfirst($order[0]['serving_option']), 0, 1);
            $pdf->Ln(5);

            // Items
            $pdf->Cell(60, 10, 'Description', 1);
            $pdf->Cell(10, 10, 'Qty', 1, 0, 'C');
            $pdf->Cell(30, 10, 'Price', 1, 1, 'R');

            foreach ($order as $item) {
                $pdf->Cell(60, 10, $item['food_details'], 0);
                $pdf->Cell(10, 10, $item['quantity'], 0, 0, 'C');
                $pdf->Cell(30, 10, '£' . number_format($item['price'], 2), 0, 1, 'R');
            }

            $pdf->Ln(5);

            // Total
            $pdf->Cell(60, 10, 'Total', 0);
            $pdf->Cell(10, 10, '', 0);
            $pdf->Cell(30, 10, '£' . number_format($order[0]['order_amount'], 2), 0, 1, 'R');
            $pdf->Ln(10);

            // Footer
            $pdf->Cell(0, 10, 'Thank you for dining with us!', 0, 1, 'C');

            // Output PDF
            $pdf->Output('I', 'receipt.pdf');
        } else {
            echo "Order not found.";
        }
    } else {
        echo "Invalid Order ID.";
    }
} catch (PDOException $e) {
    echo "Connection failed: " . $e->getMessage();
}
?>
